==> nb_utils-4.2.1.tar.gz: lib/src/widgets/SettingItemWidget.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

/// SettingItemWidget
class SettingItemWidget extends StatelessWidget {
  static String tag = '/SettingItemWidget';

  final String title;
  final String? subTitle;
  final Widget? leading;
  final Widget? trailing;
  final TextStyle? titleTextStyle;
  final TextStyle? subTitleTextStyle;
  final Function? onTap;
  final EdgeInsets? padding;
  final int paddingAfterLeading;
  final int paddingBeforeTrailing;
  final Color? titleTextColor;
  final Color? subTitleTextColor;
  final Color? hoverColor;
  final Color? splashColor;
  final Decoration? decoration;
  final double? borderRadius;

  SettingItemWidget({
    required this.title,
    this.onTap,
    this.subTitle = '',
    this.leading,
    this.trailing,
    this.titleTextStyle,
    this.subTitleTextStyle,
    this.padding,
    this.paddingAfterLeading = 16,
    this.paddingBeforeTrailing = 16,
    this.titleTextColor,
    this.subTitleTextColor,
    this.decoration,
    this.borderRadius,
    this.hoverColor,
    this.splashColor,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: padding ?? EdgeInsets.all(16),
      decoration: decoration ?? BoxDecoration(),
      child: Row(
        children: [
          leading ?? SizedBox(),
          paddingAfterLeading.width.visible(leading != null),
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                title.validate(),
                style: titleTextStyle ??
                    boldTextStyle(
                        color: titleTextColor ?? textPrimaryColorGlobal),
                maxLines: 1,
                overflow: TextOverflow.ellipsis,
              ),
              4.height.visible(subTitle.validate().isNotEmpty),
              Text(
                subTitle.validate(),
                style: subTitleTextStyle ??
                    secondaryTextStyle(
                        color: subTitleTextColor ?? textSecondaryColorGlobal),
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
              ).visible(subTitle.validate().isNotEmpty),
            ],
          ).expand(),
          paddingBeforeTrailing.width.visible(trailing != null),
          trailing ?? SizedBox(),
        ],
      ),
    ).onTap(
      () {
        onTap?.call();
      },
      borderRadius: BorderRadius.circular(borderRadius.validate()),
      hoverColor: hoverColor,
      splashColor: splashColor,
    );
  }
}

==> nb_utils-4.2.11.tar.gz: lib/src/widgets/SettingItemWidget.dart <==
import 'package:flutter/material.dart';
import 'package:nb_utils/nb_utils.dart';

/// SettingItemWidget
class SettingItemWidget extends StatelessWidget {
  static String tag = '/SettingItemWidget';

  final String title;
  final String? subTitle;
  final Widget? leading;
  final Widget? trailing;
  final TextStyle? titleTextStyle;
  final TextStyle? subTitleTextStyle;
  final Function? onTap;
  final EdgeInsets? padding;
  final int paddingAfterLeading;
  final int paddingBeforeTrailing;
  final Color? titleTextColor;
  final Color? subTitleTextColor;
  final Color? hoverColor;
  final Color? splashColor;
  final Decoration? decoration;
  final double? borderRadius;

  SettingItemWidget({
    required this.title,
    this.onTap,
    this.subTitle = '',
    this.leading,
    this.trailing,
    this.titleTextStyle,
    this.subTitleTextStyle,
    this.padding,
    this.paddingAfterLeading = 16,
    this.paddingBeforeTrailing = 16,
    this.titleTextColor,
    this.subTitleTextColor,
    this.decoration,
    this.borderRadius,
    this.hoverColor,
    this.splashColor,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: padding ?? EdgeInsets.symmetric(horizontal: 16, vertical: 14),
      decoration: decoration ?? BoxDecoration(),
      child: Row(
        children: [
          leading ?? SizedBox(),
          paddingAfterLeading.width.visible(leading != null),
          Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                title.validate(),
                style: titleTextStyle ??
                    boldTextStyle(
                        color: titleTextColor ?? textPrimaryColorGlobal),
                maxLines: 1,
                overflow: TextOverflow.ellipsis,
              ),
              4.height.visible(subTitle.validate().isNotEmpty),
              Text(
                subTitle.validate(),
                style: subTitleTextStyle ??
                    secondaryTextStyle(
                        color: subTitleTextColor ?? textSecondaryColorGlobal),
                maxLines: 2,
                overflow: TextOverflow.ellipsis,
              ).visible(subTitle.validate().isNotEmpty),
            ],
          ).expand(),
          paddingBeforeTrailing.width.visible(trailing != null),
          trailing ?? SizedBox(),
        ],
      ),
    ).onTap(
      () {
        onTap?.call();
      },
      borderRadius: BorderRadius.circular(borderRadius.validate()),
      hoverColor: hoverColor,
      splashColor: splashColor,
    );
  }
}
